export * from '@solana/accounts';
export * from '@solana/addresses';
export * from '@solana/codecs';
export * from '@solana/errors';
import { pipe } from '@solana/functional';
export * from '@solana/functional';
export * from '@solana/instructions';
export * from '@solana/keys';
export * from '@solana/programs';
import { createSolanaRpc } from '@solana/rpc';
export * from '@solana/rpc';
export * from '@solana/rpc-parsed-types';
import { createSolanaRpcSubscriptions } from '@solana/rpc-subscriptions';
export * from '@solana/rpc-subscriptions';
export * from '@solana/rpc-types';
import { isTransactionSigner, setTransactionMessageFeePayerSigner } from '@solana/signers';
export * from '@solana/signers';
import { createTransactionMessage, setTransactionMessageLifetimeUsingBlockhash, setTransactionMessageFeePayer, appendTransactionMessageInstructions } from '@solana/transaction-messages';
export * from '@solana/transaction-messages';
export * from '@solana/transactions';
export { createRpcMessage } from '@solana/rpc-spec-types';

// src/index.ts

// src/core/const.ts
var LAMPORTS_PER_SOL = 1e9;
function getPublicSolanaRpcUrl(cluster) {
  switch (cluster) {
    case "devnet":
      return "https://api.devnet.solana.com";
    case "testnet":
      return "https://api.testnet.solana.com";
    case "mainnet-beta":
      return "https://api.mainnet-beta.solana.com";
    case "localnet":
      return "http://127.0.0.1:8899";
    default:
      throw new Error("Invalid cluster moniker");
  }
}
function createSolanaClient({
  urlOrMoniker,
  rpcConfig,
  rpcSubscriptionsConfig
}) {
  if (typeof urlOrMoniker == "string") {
    try {
      urlOrMoniker = new URL(urlOrMoniker);
    } catch (err) {
      try {
        urlOrMoniker = new URL(getPublicSolanaRpcUrl(urlOrMoniker));
      } catch (err2) {
        throw new Error("Invalid URL or cluster moniker");
      }
    }
  }
  const rpc = createSolanaRpc(urlOrMoniker.toString(), rpcConfig);
  if (urlOrMoniker.protocol.endsWith("s")) urlOrMoniker.protocol = "wss";
  else urlOrMoniker.protocol = "ws";
  const rpcSubscriptions = createSolanaRpcSubscriptions(
    urlOrMoniker.toString(),
    rpcSubscriptionsConfig
  );
  return {
    rpc,
    rpcSubscriptions
  };
}

// src/core/explorer.ts
function getExplorerLink(props) {
  let url = null;
  if (!props.cluster) props.cluster = "mainnet-beta";
  if ("address" in props) {
    url = new URL(`https://explorer.solana.com/address/${props.address}`);
  } else if ("transaction" in props) {
    url = new URL(`https://explorer.solana.com/tx/${props.transaction}`);
  } else if ("block" in props) {
    url = new URL(`https://explorer.solana.com/block/${props.block}`);
  }
  if (!url) throw new Error("Invalid Solana Explorer URL created");
  if (props.cluster !== "mainnet-beta") {
    if (props.cluster === "localnet") {
      url.searchParams.set("cluster", "custom");
      url.searchParams.set("customUrl", "http://localhost:8899");
    } else {
      url.searchParams.set("cluster", props.cluster);
    }
  }
  return url;
}
function createTransaction({
  version,
  feePayer,
  instructions,
  latestBlockhash
}) {
  return pipe(
    createTransactionMessage({ version }),
    (tx) => {
      if (latestBlockhash) {
        tx = setTransactionMessageLifetimeUsingBlockhash(latestBlockhash, tx);
      }
      if (typeof feePayer !== "string" && "address" in feePayer && isTransactionSigner(feePayer)) {
        return setTransactionMessageFeePayerSigner(feePayer, tx);
      } else return setTransactionMessageFeePayer(feePayer, tx);
    },
    (tx) => appendTransactionMessageInstructions(instructions, tx)
  );
}

// src/core/accounts.ts
function getMinimumBalanceForRentExemption(space = 0) {
  const RENT = {
    /**
     * Account storage overhead for calculation of base rent. (aka the number of bytes required to store an account with no data.
     */
    ACCOUNT_STORAGE_OVERHEAD: 128n,
    /**
     * Amount of time (in years) a balance must include rent for the account to
     * be rent exempt.
     */
    DEFAULT_EXEMPTION_THRESHOLD: BigInt(Math.floor(2 * 1e3)) / 1000n,
    /**
     * Default rental rate in lamports/byte-year. This calculation is based on:
     * - 10^9 lamports per SOL
     * - $1 per SOL
     * - $0.01 per megabyte day
     * - $3.65 per megabyte year
     */
    DEFAULT_LAMPORTS_PER_BYTE_YEAR: BigInt(
      Math.floor(1e9 / 100 * 365 / (1024 * 1024))
    )
  };
  return (RENT.ACCOUNT_STORAGE_OVERHEAD + BigInt(space)) * RENT.DEFAULT_LAMPORTS_PER_BYTE_YEAR * RENT.DEFAULT_EXEMPTION_THRESHOLD / 1n;
}

export { LAMPORTS_PER_SOL, createSolanaClient, createTransaction, getExplorerLink, getMinimumBalanceForRentExemption, getPublicSolanaRpcUrl };
//# sourceMappingURL=index.native.mjs.map
//# sourceMappingURL=index.native.mjs.map